Class Modules

java.lang.Object
org.openide.modules.Modules

public class Modules extends Object
Information about the set of available modules.
Since:
org.openide.modules 7.19
  • Constructor Details

    • Modules

      protected Modules()
      Constructor for subclasses.
  • Method Details

    • getDefault

      public static Modules getDefault()
      Gets the singleton set of modules. An implementation of this service should be registered by the module system. The fallback implementation implements ownerOf(Class) using a linear search.
      Returns:
      the default instance
    • findCodeNameBase

      public ModuleInfo findCodeNameBase(String cnb)
    • ownerOf

      public ModuleInfo ownerOf(Class<?> clazz)
      Finds the module which loaded a class.
      Parameters:
      clazz - a class
      Returns:
      the owner of the class, or null if it is not owned by any module
      See Also: