Class Modules
java.lang.Object
org.openide.modules.Modules
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfindCodeNameBase(String cnb) static ModulesGets the singleton set of modules.Finds the module which loaded a class.
-
Constructor Details
-
Modules
protected Modules()Constructor for subclasses.
-
-
Method Details
-
getDefault
Gets the singleton set of modules. An implementation of this service should be registered by the module system. The fallback implementation implementsownerOf(Class)using a linear search.- Returns:
- the default instance
-
findCodeNameBase
-
ownerOf
Finds the module which loaded a class.- Parameters:
clazz- a class- Returns:
- the owner of the class, or null if it is not owned by any module
- See Also:
-